@@ -185,26 +185,13 @@ EVENT_SINK_INVOKE(MailItemEvents)
         }
       case Read:
         {
-          if (g_ol_version_major < 14)
-            {
-              /* In Outlook 2007 there is no Before read event.
-                 We change the message class in message-events to
-                 prevent that outlook parses the mail itself but
-                 we still need to update our mail object accordingly.
-                 So we call pre_process here gain although the message
-                 class already was changed. */
-              if (m_mail->pre_process_message ())
-                {
-                  log_error ("%s:%s: Pre process message failed.",
-                             SRCNAME, __func__);
-                }
-            }
           log_oom_extra ("%s:%s: Read : %p",
                          SRCNAME, __func__, m_mail);
           if (!m_mail->is_crypto_mail())
             {
               /* Ensure that no wrong sigstatus is shown */
-              gpgoladdin_invalidate_ui ();
+              CloseHandle(CreateThread (NULL, 0, delayed_invalidate_ui, (LPVOID) this, 0,
+                                        NULL));
               break;
             }
           if (m_mail->set_uuid ())
